function y = my_filt(h,x);
%function y = my_filt(h,x);
%
% MY_FILT  --  This function implements the "real-time" convolution
%              algorithm.
%
% Input Parameters:
%   h  -- the impulse response of the filter
%   x  -- the signal to be filtered
%
% Output Parameters:
%   y  -- the filtered signal
%

% Initialize the output vector; should be same size as 'x'
y = zeros(size(x));

% Make x and h column vectors, regardless of incoming size
x = shiftdim(x);
h = shiftdim(h);

% Buffer is just a column vector.  We initialize it to
%    all zeros to begin with.
buffer = zeros(size(h));

for n = 1:length(x)
    
    % current_sample is the single input to our "filtering box"
    current_sample = x(n);
    
    % Update the buffer.  Discard buffer(end), and put
    %   current_sample at the front of the buffer.
    
    buffer = ?
   
    % From h and the contents of buffer, we can calculate
    %   the next output sample
    
    y(b) = ?

end